@@ -64,7 +64,7 @@ sub register {
 		$template = "/$template";
 		my $route = $self->get_best_matched_route($template,$r);
 		my $routep = $route->to_string;
-		$template =~ s/$routep//;
+		$template =~ s/^$routep//;
         # support for /url_component/index
         my $tr = $route->any($template)->to(app => $ctl, action => 'route');
         $tr->any('/');
@@ -130,7 +130,7 @@ Mojolicious::Plugin::AutoRoutePm - Mojolicious plugin to create routes by *.pm m
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
